FastaBatch

Struct FastaBatch 

pub struct FastaBatch<'a> { /* private fields */ }
A batch of borrowed FASTA records.

Implementations

Source

impl<'a> FastaBatch<'a>

pub fn len(&self) -> usize

Number of records in the batch.

pub fn is_empty(&self) -> bool

Whether the batch has no records.

pub fn bytes(&self) -> &'a [u8]

Raw bytes backing this batch.

pub fn record_refs(&self) -> &'a [FastaRecordRef]

Record ranges within bytes.

pub fn first_record_index(&self) -> u64

Zero-based index of the first record in this batch.

pub fn records(&self) -> impl Iterator<Item = FastaRecord<'_>>

Iterate borrowed records in this batch.

pub fn to_owned_batch(&self) -> OwnedFastaBatch

Copy this borrowed batch into an owned transferable batch.