pub struct OwnedFastaBatch { /* private fields */ }Expand description
Owned FASTA batch that can be moved to worker threads.
Implementations
Sourceimpl OwnedFastaBatch
impl OwnedFastaBatch
Sourcepub fn record_refs(&self) -> &[FastaRecordRef]
pub fn record_refs(&self) -> &[FastaRecordRef]
Record ranges within bytes.
Sourcepub fn first_record_index(&self) -> u64
pub fn first_record_index(&self) -> u64
Zero-based index of the first record in this batch.
Sourcepub fn records(&self) -> impl Iterator<Item = OwnedFastaRecord<'_>>
pub fn records(&self) -> impl Iterator<Item = OwnedFastaRecord<'_>>
Iterate borrowed records in this owned batch.