pub struct FastaBatch<'a> { /* private fields */ }Expand description
A batch of borrowed FASTA records.
Implementations
Sourceimpl<'a> FastaBatch<'a>
impl<'a> FastaBatch<'a>
Sourcepub fn record_refs(&self) -> &'a [FastaRecordRef]
pub fn record_refs(&self) -> &'a [FastaRecordRef]
Record ranges within bytes.
Sourcepub fn first_record_index(&self) -> u64
pub fn first_record_index(&self) -> u64
Zero-based index of the first record in this batch.
Sourcepub fn records(&self) -> impl Iterator<Item = FastaRecord<'_>>
pub fn records(&self) -> impl Iterator<Item = FastaRecord<'_>>
Iterate borrowed records in this batch.
Sourcepub fn to_owned_batch(&self) -> OwnedFastaBatch
pub fn to_owned_batch(&self) -> OwnedFastaBatch
Copy this borrowed batch into an owned transferable batch.